/* LIBGIMP - The GIMP Library
 * Copyright (C) 1995-2003 Peter Mattis and Spencer Kimball
 *
 * gimpimagesamplepoints_pdb.h
 *
 * This library is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see
 * <https://www.gnu.org/licenses/>.
 */

/* NOTE: This file is auto-generated by pdbgen.pl */

#if !defined (__GIMP_H_INSIDE__) && !defined (GIMP_COMPILATION)
#error "Only <libgimp/gimp.h> can be included directly."
#endif

#ifndef __GIMP_IMAGE_SAMPLE_POINTS_PDB_H__
#define __GIMP_IMAGE_SAMPLE_POINTS_PDB_H__

G_BEGIN_DECLS

/* For information look into the C source or the html documentation */


gint32   gimp_image_add_sample_point          (gint32  image_ID,
                                               gint    position_x,
                                               gint    position_y);
gboolean gimp_image_delete_sample_point       (gint32  image_ID,
                                               gint32  sample_point_ID);
gint32   gimp_image_find_next_sample_point    (gint32  image_ID,
                                               gint32  sample_point_ID);
gint     gimp_image_get_sample_point_position (gint32  image_ID,
                                               gint32  sample_point_ID,
                                               gint   *position_y);


G_END_DECLS

#endif /* __GIMP_IMAGE_SAMPLE_POINTS_PDB_H__ */
